@@ -1,3 +1,4 @@
+import csv
 import ntpath
 import os
 import warnings
@@ -5,10 +6,14 @@ import warnings
 from pyaedt.application.Analysis import Analysis
 from pyaedt.generic.configurations import Configurations
 from pyaedt.generic.general_methods import _retry_ntimes
+from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
+from pyaedt.modeler.Model2D import Modeler2D
 from pyaedt.modeler.Model3D import Modeler3D
+from pyaedt.modeler.stackup_3d import Stackup3D
 from pyaedt.modules.Mesh import Mesh
+from pyaedt.modules.MeshIcepak import IcepakMesh
 
 if is_ironpython:
     from pyaedt.modules.PostProcessor import PostProcessor
@@ -57,6 +62,9 @@ class FieldAnalysis3D(Analysis, object):
     student_version : bool, optional
         Whether to enable the student version of AEDT. The default
         is ``False``.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
     """
 
     def __init__(
@@ -73,6 +81,7 @@ class FieldAnalysis3D(Analysis, object):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         Analysis.__init__(
             self,
@@ -88,11 +97,12 @@ class FieldAnalysis3D(Analysis, object):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
         self._osolution = self._odesign.GetModule("Solutions")
         self._oboundary = self._odesign.GetModule("BoundarySetup")
-        self._modeler = Modeler3D(self)
-        self._mesh = Mesh(self)
+        self._modeler = Modeler2D(self) if application in ["Maxwell 2D", "2D Extractor"] else Modeler3D(self)
+        self._mesh = IcepakMesh(self) if application == "Icepak" else Mesh(self)
         self._post = PostProcessor(self)
         self._configurations = Configurations(self)
 
@@ -144,7 +154,7 @@ class FieldAnalysis3D(Analysis, object):
 
         Returns
         -------
-        :class:`pyaedt.modules.Mesh.Mesh`
+        :class:`pyaedt.modules.Mesh.Mesh` or :class:`pyaedt.modules.MeshIcepak.IcepakMesh`
         """
         return self._mesh
 
@@ -376,7 +386,6 @@ class FieldAnalysis3D(Analysis, object):
                     return val
         return None
 
-    # TODO Refactor this
     @pyaedt_function_handler()
     def copy_solid_bodies_from(self, design, object_list=None, no_vacuum=True, no_pec=True, include_sheets=False):
         """Copy a list of objects from one design to the active design.
@@ -601,21 +610,19 @@ class FieldAnalysis3D(Analysis, object):
         >>> obj_names_list = [box1.name, box2.name, cylinder1.name, cylinder2.name]
         >>> hfss.assign_material(obj_names_list, "aluminum")
         """
-        mat = mat.lower()
         selections = self.modeler.convert_to_selections(obj, True)
 
-        mat_exists = False
-        if mat in self.materials.material_keys:
-            mat_exists = True
-        if mat_exists or self.materials.checkifmaterialexists(mat):
-            Mat = self.materials.material_keys[mat]
-            if mat_exists:
-                Mat.update()
+        if mat.lower() not in self.materials.material_keys:
+            matobj = self.materials._aedmattolibrary(mat)
+        else:
+            matobj = self.materials.material_keys[mat.lower()]
+
+        if matobj:
             self.logger.info("Assign Material " + mat + " to object " + str(selections))
             for el in selections:
-                self.modeler[el].material_name = mat
-                self.modeler[el].color = self.materials.material_keys[mat].material_appearance
-                if Mat.is_dielectric():
+                self.modeler[el].material_name = matobj.name
+                self.modeler[el].color = matobj.material_appearance
+                if matobj.is_dielectric():
                     self.modeler[el].solve_inside = True
                 else:
                     self.modeler[el].solve_inside = False
@@ -638,6 +645,8 @@ class FieldAnalysis3D(Analysis, object):
 
         >>> oEditor.GetObjectsByMaterial
         """
+        if len(self.modeler.objects) != len(self.modeler.object_names):
+            self.modeler.refresh_all_ids()
         cond = self.materials.conductors
 
         obj_names = []
@@ -659,9 +668,184 @@ class FieldAnalysis3D(Analysis, object):
         ----------
         >>> oEditor.GetObjectsByMaterial
         """
+        if len(self.modeler.objects) != len(self.modeler.object_names):
+            self.modeler.refresh_all_ids()
         diel = self.materials.dielectrics
         obj_names = []
         for obj_val in list(self.modeler.objects.values()):
             if obj_val.material_name in diel:
                 obj_names.append(obj_val.name)
         return obj_names
+
+    @pyaedt_function_handler()
+    def _create_dataset_from_sherlock(self, material_string, property_name="Mass_Density"):
+        mats = material_string.split(",")
+        mat_temp = [[i.split("@")[0], i.split("@")[1]] for i in mats]
+        nominal_id = int(len(mat_temp) / 2)
+        nominal_val = float(mat_temp[nominal_id - 1][0])
+        ds_name = generate_unique_name(property_name)
+        self.create_dataset(
+            ds_name,
+            [float(i[1].replace("C", "").replace("K", "").replace("F", "")) for i in mat_temp],
+            [float(i[0]) / nominal_val for i in mat_temp],
+        )
+        return nominal_val, "$" + ds_name
+
+    @pyaedt_function_handler()
+    def assignmaterial_from_sherlock_files(self, csv_component, csv_material):
+        """Assign material to objects in a design based on a CSV file obtained from Sherlock.
+
+        Parameters
+        ----------
+        csv_component :  str
+            Name of the CSV file containing the component properties, including the
+            material name.
+        csv_material : str
+            Name of the CSV file containing the material properties.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        References
+        ----------
+
+        >>> oEditor.AssignMaterial
+        """
+        with open(csv_material) as csvfile:
+            csv_input = csv.reader(csvfile)
+            material_header = next(csv_input)
+            data = list(csv_input)
+            k = 0
+            material_data = {}
+            for el in material_header:
+                material_data[el] = [i[k] for i in data]
+                k += 1
+        with open(csv_component) as csvfile:
+            csv_input = csv.reader(csvfile)
+            component_header = next(csv_input)
+            data = list(csv_input)
+            k = 0
+            component_data = {}
+            for el in component_header:
+                component_data[el] = [i[k] for i in data]
+                k += 1
+        all_objs = self.modeler.object_names
+        i = 0
+        for mat in material_data["Name"]:
+            list_mat_obj = [
+                "COMP_" + rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if md == mat
+            ]
+            list_mat_obj += [rd for rd, md in zip(component_data["Ref Des"], component_data["Material"]) if md == mat]
+            list_mat_obj = [mo for mo in list_mat_obj if mo in all_objs]
+            if list_mat_obj:
+                newmat = self.materials.checkifmaterialexists(mat)
+                if not newmat:
+                    newmat = self.materials.add_material(mat.lower())
+                if "Material Density" in material_data:
+                    if "@" in material_data["Material Density"][i] and "," in material_data["Material Density"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            material_data["Material Density"][i], "Mass_Density"
+                        )
+                        newmat.mass_density = nominal_val
+                        newmat.mass_density.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
+                    else:
+                        value = material_data["Material Density"][i]
+                        newmat.mass_density = value
+                if "Thermal Conductivity" in material_data:
+                    if (
+                        "@" in material_data["Thermal Conductivity"][i]
+                        and "," in material_data["Thermal Conductivity"][i]
+                    ):
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            material_data["Thermal Conductivity"][i], "Thermal_Conductivity"
+                        )
+                        newmat.thermal_conductivity = nominal_val
+                        newmat.thermal_conductivity.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
+                    else:
+                        value = material_data["Thermal Conductivity"][i]
+                        newmat.thermal_conductivity = value
+                if "Material CTE" in material_data:
+                    if "@" in material_data["Material CTE"][i] and "," in material_data["Material CTE"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            material_data["Material CTE"][i], "CTE"
+                        )
+                        newmat.thermal_expansion_coefficient = nominal_val
+                        newmat.thermal_expansion_coefficient.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
+                    else:
+                        value = material_data["Material CTE"][i]
+                        newmat.thermal_expansion_coefficient = value
+                if "Poisson Ratio" in material_data:
+                    if "@" in material_data["Poisson Ratio"][i] and "," in material_data["Poisson Ratio"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            material_data["Poisson Ratio"][i], "Poisson_Ratio"
+                        )
+                        newmat.poissons_ratio = nominal_val
+                        newmat.poissons_ratio.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
+                    else:
+                        value = material_data["Poisson Ratio"][i]
+                        newmat.poissons_ratio = value
+                if "Elastic Modulus" in material_data:
+                    if "@" in material_data["Elastic Modulus"][i] and "," in material_data["Elastic Modulus"][i]:
+                        nominal_val, dataset_name = self._create_dataset_from_sherlock(
+                            material_data["Elastic Modulus"][i], "Youngs_Modulus"
+                        )
+                        newmat.youngs_modulus = nominal_val
+                        newmat.youngs_modulus.thermalmodifier = "pwl({}, Temp)".format(dataset_name)
+                    else:
+                        value = material_data["Elastic Modulus"][i]
+                        newmat.youngs_modulus = value
+                self.assign_material(list_mat_obj, mat)
+
+                for obj_name in list_mat_obj:
+                    if not self.modeler[obj_name].surface_material_name:
+                        self.modeler[obj_name].surface_material_name = "Steel-oxidised-surface"
+            i += 1
+            all_objs = [ao for ao in all_objs if ao not in list_mat_obj]
+        return True
+
+    @pyaedt_function_handler()
+    def cleanup_solution(self, variations="All", entire_solution=True, field=True, mesh=True, linked_data=True):
+        """Delete a set of Solution Variations or part of them.
+
+        Parameters
+        ----------
+        variations : List, str, optional
+            All variations to delete. Default is `"All"` which deletes all available solutions.
+        entire_solution : bool, optional
+            Either if delete entire Solution or part of it. If `True` other booleans will be ignored
+            as solution will be entirely deleted.
+        field : bool, optional
+            Either if delete entire Fields of variation or not. Default is `True`.
+        mesh : bool, optional
+            Either if delete entire Mesh of variation or not. Default is `True`.
+        linked_data : bool, optional
+            Either if delete entire Linked Data of variation or not. Default is `True`.
+
+        Returns
+        -------
+        bool
+            `True` if Delete operation succeeded.
+        """
+        if isinstance(variations, str):
+            variations = [variations]
+        if entire_solution:
+            self.odesign.DeleteFullVariation(variations, linked_data)
+        elif field:
+            self.odesign.DeleteFieldVariation(variations, mesh, linked_data)
+        elif linked_data:
+            self.odesign.DeleteLinkedDataVariation(variations)
+        return True
+
+    @pyaedt_function_handler
+    def add_stackup_3d(self):
+        """Create a stackup 3D object.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.stackup_3d.Stackup3D`
+            ``True`` when delete operation is successful.
+        """
+        st = Stackup3D(self)
+        return st
