@@ -55,6 +55,9 @@ class FieldAnalysis3DLayout(Analysis):
     student_version : bool, optional
         Whether to enable the student version of AEDT. The default
         is ``False``.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
 
     """
 
@@ -72,6 +75,7 @@ class FieldAnalysis3DLayout(Analysis):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         Analysis.__init__(
             self,
@@ -87,13 +91,13 @@ class FieldAnalysis3DLayout(Analysis):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
         self._osolution = self._odesign.GetModule("SolveSetups")
         self._oexcitation = self._odesign.GetModule("Excitations")
         self._oboundary = self._odesign.GetModule("Excitations")
         self.logger.info("Analysis Loaded")
         self._modeler = Modeler3DLayout(self)
-        self._modeler.init_padstacks()
         self.logger.info("Modeler Loaded")
         self._mesh = Mesh3d(self)
         self._post = PostProcessor(self)
