@@ -32,6 +32,7 @@ class FieldAnalysisRMxprt(Analysis):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         Analysis.__init__(
             self,
@@ -47,6 +48,7 @@ class FieldAnalysisRMxprt(Analysis):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
 
         self._modeler = ModelerRMxprt(self)
