@@ -24,6 +24,7 @@ from pyaedt.generic.constants import AEDT_UNITS
 from pyaedt.generic.constants import SI_UNITS
 from pyaedt.generic.constants import unit_system
 from pyaedt.generic.general_methods import is_number, is_array
+from pyaedt import is_ironpython
 
 
 class CSVDataset:
@@ -676,30 +677,17 @@ class VariableManager(object):
         var_dict = {}
         all_names = {}
         for obj in object_list:
-            if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
-                listvar = list(obj.GetChildObject("Variables").GetChildNames())
-            else:
-                listvar = list(obj.GetVariables())
+            listvar = self._get_var_list_from_aedt(obj)
             for variable_name in listvar:
                 variable_expression = self.get_expression(variable_name)
                 all_names[variable_name] = variable_expression
-                try:
-                    value = Variable(variable_expression)
-                    if is_array(value.value):
-                        var_dict[variable_name] = value
-                    elif independent and is_number(value.value):
-                        var_dict[variable_name] = value
-                    elif dependent and isinstance(value.value, str):
-                        float_value = self._app.get_evaluated_value(variable_name)
-                        var_dict[variable_name] = Expression(
-                            variable_expression, float_value, all_names, name=variable_name, app=self._app
-                        )
-                except:
-                    if dependent:
-                        float_value = self._app.get_evaluated_value(variable_name)
-                        var_dict[variable_name] = Expression(
-                            variable_expression, float_value, all_names, name=variable_name, app=self._app
-                        )
+                # try:
+                si_value = self._app.get_evaluated_value(variable_name)
+                value = Variable(variable_expression, None, si_value, all_names, name=variable_name, app=self._app)
+                if independent and (is_array(value._calculated_value) or is_number(value._calculated_value)):
+                    var_dict[variable_name] = value
+                elif dependent and not is_array(value._calculated_value) and not is_number(value._calculated_value):
+                    var_dict[variable_name] = value
         return var_dict
 
     @pyaedt_function_handler()
@@ -811,13 +799,21 @@ class VariableManager(object):
             description = ""
 
         desktop_object = self.aedt_object(variable_name)
-        test = desktop_object.GetName()
-        proj_name = self._oproject.GetName()
-        var_type = "Project" if "$" in variable_name[0] else "Local"
-        if circuit_parameter and self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design"]:
-            tab_name = "DefinitionParameterTab"
+        if variable_name.startswith("$"):
+            tab_name = "ProjectVariableTab"
+            prop_server = "ProjectVariables"
         else:
-            tab_name = "{0}VariableTab".format(var_type)
+            tab_name = "LocalVariableTab"
+            prop_server = "LocalVariables"
+            if circuit_parameter and self._app.design_type in [
+                "HFSS 3D Layout Design",
+                "Circuit Design",
+                "Maxwell Circuit",
+                "Twin Builder",
+            ]:
+                tab_name = "DefinitionParameterTab"
+            if self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design", "Maxwell Circuit", "Twin Builder"]:
+                prop_server = "Instance:{}".format(desktop_object.GetName())
 
         prop_type = "VariableProp"
         if postprocessing or "post" in variable_name.lower()[0:5]:
@@ -848,20 +844,8 @@ class VariableManager(object):
             raise Exception("Unhandled input type to the design property or project variable.")  # pragma: no cover
 
         # Get all design and project variables in lower case for a case-sensitive comparison
-        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
-            var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
-        else:
-            var_list = list(desktop_object.GetVariables())  # pragma: no cover
+        var_list = self._get_var_list_from_aedt(desktop_object)
         lower_case_vars = [var_name.lower() for var_name in var_list]
-        if (
-            self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design", "Maxwell Circuit"]
-            and "$" not in variable_name
-        ):
-            prop_server = "Instance:{}".format(desktop_object.GetName())
-        elif self._app.design_type == "Circuit Design" and circuit_parameter:
-            prop_server = "DefinitionParameters"
-        else:
-            prop_server = "{0}Variables".format(var_type)
 
         if variable_name.lower() not in lower_case_vars:
             try:
@@ -942,12 +926,9 @@ class VariableManager(object):
                     ],
                 ]
             )
-        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
-            var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
-        else:
-            var_list = list(desktop_object.GetVariables())  # pragma: no cover
+        var_list = self._get_var_list_from_aedt(desktop_object)
         lower_case_vars = [var_name.lower() for var_name in var_list]
-        if variable_name not in lower_case_vars:
+        if variable_name.lower() not in lower_case_vars:
             return False
         return True
 
@@ -1015,12 +996,8 @@ class VariableManager(object):
         """
         desktop_object = self.aedt_object(var_name)
         var_type = "Project" if desktop_object == self._oproject else "Local"
-        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
-            var_list = list(desktop_object.GetChildObject("Variables").GetChildNames())
-        else:
-            var_list = list(desktop_object.GetVariables())  # pragma: no cover
+        var_list = self._get_var_list_from_aedt(desktop_object)
         lower_case_vars = [var_name.lower() for var_name in var_list]
-
         if var_name.lower() in lower_case_vars:
             try:
                 desktop_object.ChangeProperty(
@@ -1038,6 +1015,15 @@ class VariableManager(object):
                 pass
         return False
 
+    @pyaedt_function_handler()
+    def _get_var_list_from_aedt(self, desktop_object):
+        var_list = []
+        if self._app._is_object_oriented_enabled() and self._app.design_type != "Maxwell Circuit":
+            var_list += list(desktop_object.GetChildObject("Variables").GetChildNames())
+        tmp = [i for i in list(desktop_object.GetVariables()) if i not in var_list]
+        var_list += tmp
+        return var_list
+
 
 class Variable(object):
     """Stores design properties and project variables and provides operations to perform on them.
@@ -1070,16 +1056,39 @@ class Variable(object):
 
     """
 
-    def __init__(self, value, units=None):
-
+    def __init__(
+        self,
+        expression,
+        units=None,
+        si_value=None,
+        full_variables=None,
+        name=None,
+        app=None,
+        readonly=False,
+        hidden=False,
+        description=None,
+        postprocessing=False,
+        circuit_parameter=True,
+    ):
+        if not full_variables:
+            full_variables = {}
+        self._variable_name = name
+        self._app = app
+        self._readonly = readonly
+        self._hidden = hidden
+        self._postprocessing = postprocessing
+        self._circuit_parameter = circuit_parameter
+        self._description = description
         if units:
             if unit_system(units):
                 specified_units = units
-
         self._units = None
-        self._expression = value
-        self._value, self._units = decompose_variable_value(value)
-
+        self._expression = expression
+        self._calculated_value, self._units = decompose_variable_value(expression, full_variables)
+        if si_value:
+            self._value = si_value
+        else:
+            self._value = self._calculated_value
         # If units have been specified, check for a conflict and otherwise use the specified unit system
         if units:
             assert not self._units, "The unit specification {} is inconsistent with the identified units {}.".format(
@@ -1087,7 +1096,7 @@ class Variable(object):
             )
             self._units = specified_units
 
-        if is_number(self._value):
+        if not si_value and is_number(self._value):
             try:
                 scale = AEDT_UNITS[self.unit_system][self._units]
             except KeyError:
@@ -1097,6 +1106,173 @@ class Variable(object):
             else:
                 self._value = self._value * scale
 
+    @property
+    def _aedt_obj(self):
+        if "$" in self._variable_name and self._app:
+            return self._app._oproject
+        elif self._app:
+            return self._app._odesign
+        return None
+
+    @pyaedt_function_handler()
+    def _update_var(self):
+        if self._app:
+            return self._app.variable_manager.set_variable(
+                self._variable_name,
+                self._expression,
+                readonly=self._readonly,
+                postprocessing=self._postprocessing,
+                circuit_parameter=self._circuit_parameter,
+                description=self._description,
+                hidden=self._hidden,
+            )
+        return False
+
+    @property
+    def name(self):
+        """Variable name."""
+        return self._variable_name
+
+    @name.setter
+    def name(self, value):
+        fallback_val = self._variable_name
+        self._variable_name = value
+        if not self._update_var():
+            self._variable_name = fallback_val
+            if self._app:
+                self._app.logger.error('"Failed to update property "name".')
+
+    @property
+    def read_only(self):
+        """Read-only flag value."""
+        if self._app:
+            try:
+                if not is_ironpython:
+                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_ReadOnly
+                else:  # pragma: no cover
+                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_ReadOnly()
+
+            except:
+                return self._readonly
+        return self._readonly
+
+    @read_only.setter
+    def read_only(self, value):
+        fallback_val = self._readonly
+        self._readonly = value
+        if not self._update_var():
+            self._readonly = fallback_val
+            if self._app:
+                self._app.logger.error('Failed to update property "read_only".')
+
+    @property
+    def hidden(self):
+        """Hidden flag value."""
+        if self._app:
+            try:
+                if not is_ironpython:
+                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Hidden
+                else:  # pragma: no cover
+                    return self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Hidden()
+            except:
+                return self._hidden
+        return self._hidden
+
+    @hidden.setter
+    def hidden(self, value):
+        fallback_val = self._hidden
+        self._hidden = value
+        if not self._update_var():
+            self._hidden = fallback_val
+            if self._app:
+                self._app.logger.error('Failed to update property "hidden".')
+
+    @property
+    def description(self):
+        """Description value."""
+        if self._app:
+            try:
+                if not is_ironpython:
+                    return (
+                        self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Description
+                    )
+                else:  # pragma: no cover
+                    return (
+                        self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name).Get_Description()
+                    )
+            except:
+                return self._description
+        return self._description
+
+    @description.setter
+    def description(self, value):
+        fallback_val = self._description
+        self._description = value
+        if not self._update_var():
+            self._description = fallback_val
+            if self._app:
+                self._app.logger.error('Failed to update property "description".')
+
+    @property
+    def post_processing(self):
+        """Postprocessing flag value."""
+        if self._app:
+            return True if self._variable_name in self._app.variable_manager.post_processing_variables else False
+
+    @property
+    def circuit_parameter(self):
+        """Circuit parameter flag value."""
+        if "$" in self._variable_name:
+            return False
+        if self._app.design_type in ["HFSS 3D Layout Design", "Circuit Design", "Maxwell Circuit", "Twin Builder"]:
+            prop_server = "Instance:{}".format(self._aedt_obj.GetName())
+            return (
+                True
+                if self._variable_name in self._aedt_obj.GetProperties("DefinitionParameterTab", prop_server)
+                else False
+            )
+        return False
+
+    @property
+    def expression(self):
+        """Expression."""
+        if self._aedt_obj:
+            return self._aedt_obj.GetVariableValue(self._variable_name)
+        return
+
+    @expression.setter
+    def expression(self, value):
+        fallback_val = self._expression
+        self._expression = value
+        if not self._update_var():
+            self._expression = fallback_val
+            if self._app:
+                self._app.logger.error("Failed to update property Expression.")
+
+    @property
+    def numeric_value(self):
+        """Numeric part of the expression as a float value."""
+        try:
+            if re.search(r"^[\w+]+\[\w+].*", str(self._value)):
+                var_obj = self._aedt_obj.GetChildObject("Variables").GetChildObject(self._variable_name)
+                val, _ = decompose_variable_value(var_obj.GetPropEvaluatedValue("EvaluatedValue"))
+                return val
+        except TypeError:
+            pass
+        if is_array(self._value):
+            return list(eval(self._value))
+        if is_number(self._value):
+            try:
+                scale = AEDT_UNITS[self.unit_system][self._units]
+            except KeyError:
+                scale = 1
+            if isinstance(scale, tuple):
+                return scale[0](self._value, True)
+            else:
+                return self._value / scale
+        else:
+            return self._value
+
     @property
     def unit_system(self):
         """Unit system of the expression as a string."""
@@ -1112,23 +1288,6 @@ class Variable(object):
         """Value."""
         return self._value
 
-    @property
-    def numeric_value(self):
-        """Numeric part of the expression as a float value."""
-        if is_array(self._value):
-            return list(eval(self._value))
-        if is_number(self._value):
-            try:
-                scale = AEDT_UNITS[self.unit_system][self._units]
-            except KeyError:
-                scale = 1
-            if isinstance(scale, tuple):
-                return scale[0](self._value, True)
-            else:
-                return self._value / scale
-        else:
-            return self._value
-
     @property
     def string_value(self):
         """String value.
@@ -1424,47 +1583,6 @@ class Variable(object):
     #     return self.__rtruediv__(other)
 
 
-class Expression(Variable, object):
-    """Provides a framework for manipulating variable expressions.
-
-    Parameters
-    ----------
-    expression :
-
-    float_value :
-
-    """
-
-    def __init__(self, expression, float_value, full_variables={}, name=None, app=None):
-        self._expression = expression
-        self._value = float_value
-        self._variable_name = name
-        self._app = app
-        try:
-            value, units = decompose_variable_value(expression, full_variables)
-            self._units = units
-        except:
-            self._units = ""
-
-    @property
-    def expression(self):
-        """Expression."""
-        return str(self._expression)
-
-    @property
-    def numeric_value(self):
-        """Numeric part of the expression as a float value."""
-        try:
-            if re.search(r"^[\w+]+\[\w+].*", self._value):
-                var_obj = self._app._odesign.GetChildObject("Variables").GetChildObject(self._variable_name)
-                val, _ = decompose_variable_value(var_obj.GetPropEvaluatedValue("EvaluatedValue"))
-                return val
-            else:
-                return Variable.numeric_value.fget(self)
-        except TypeError:
-            return Variable.numeric_value.fget(self)
-
-
 class DataSet(object):
     """Manages datasets.
 
@@ -1519,17 +1637,27 @@ class DataSet(object):
             x, y, z, v = (list(t) for t in zip(*sorted(zip(self.x, self.y, self.z, self.v), key=lambda e: float(e[0]))))
         else:
             x, y = (list(t) for t in zip(*sorted(zip(self.x, self.y), key=lambda e: float(e[0]))))
+
         for i in range(len(x)):
-            arg3 = []
-            arg3.append("NAME:Coordinate")
-            arg4 = ["NAME:CoordPoint"]
-            arg4.append(float(x[i]))
-            arg4.append(float(y[i]))
-            if self.z and self.name[0] == "$":
-                arg4.append(float(z[i]))
-                arg4.append(float(v[i]))
-            arg3.append(arg4)
-            arg2.append(arg3)
+            if self._app._aedt_version >= "2022.1":
+                arg3 = ["NAME:Point"]
+                arg3.append(float(x[i]))
+                arg3.append(float(y[i]))
+                if self.z and self.name[0] == "$":
+                    arg3.append(float(z[i]))
+                    arg3.append(float(v[i]))
+                arg2.append(arg3)
+            else:
+                arg3 = []
+                arg3.append("NAME:Coordinate")
+                arg4 = ["NAME:CoordPoint"]
+                arg4.append(float(x[i]))
+                arg4.append(float(y[i]))
+                if self.z and self.name[0] == "$":
+                    arg4.append(float(z[i]))
+                    arg4.append(float(v[i]))
+                arg3.append(arg4)
+                arg2.append(arg3)
         arg.append(arg2)
         return arg
 
