@@ -170,7 +170,7 @@ def release_desktop(close_projects=True, close_desktop=True):
                 desktop.CloseProject(project)
         pid = _main.oDesktop.GetProcessID()
         if not is_ironpython:
-            if settings.aedt_version >= "2022.2":
+            if settings.aedt_version >= "2022.2" and settings.use_grpc_api:
                 import ScriptEnv
 
                 ScriptEnv.Release()
@@ -290,6 +290,9 @@ class Desktop:
         Port number of which start the oDesktop communication on already existing server.
         This parameter is ignored in new server creation. It works only on 2022R2.
         Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
 
     Examples
     --------
@@ -321,6 +324,7 @@ class Desktop:
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         """Initialize desktop."""
         self._main = sys.modules["__main__"]
@@ -332,6 +336,7 @@ class Desktop:
         self._main.student_version = student_version
         self.machine = machine
         self.port = port
+        self.aedt_process_id = aedt_process_id
         if is_ironpython:
             self._main.isoutsideDesktop = False
         else:
@@ -363,7 +368,12 @@ class Desktop:
                 if StrictVersion(version_key) < StrictVersion("2022.2.0") or not settings.use_grpc_api:
                     print("Launching PyAEDT outside Electronics Desktop with CPython and Pythonnet")
                     self._init_cpython(
-                        non_graphical, new_desktop_session, version, self._main.student_version, version_key
+                        non_graphical,
+                        new_desktop_session,
+                        version,
+                        self._main.student_version,
+                        version_key,
+                        aedt_process_id,
                     )
                 else:
                     self._init_cpython_new(non_graphical, new_desktop_session, version, self._main.student_version)
@@ -382,6 +392,7 @@ class Desktop:
         settings.aedt_version = self.odesktop.GetVersion()[0:6]
         settings.machine = self.machine
         settings.port = self.port
+        self.aedt_process_id = self.odesktop.GetProcessID()  # bit of cleanup for consistency if used in future
 
         if _com == "ironpython":
             sys.path.append(
@@ -545,7 +556,16 @@ class Desktop:
         self._main.oDesktop = o_ansoft_app.GetAppDesktop()
         self._main.isoutsideDesktop = True
 
-    def _init_cpython(self, non_graphical, new_aedt_session, version, student_version, version_key):
+    def _init_cpython(
+        self,
+        non_graphical,
+        new_aedt_session,
+        version,
+        student_version,
+        version_key,
+        aedt_process_id=None,
+    ):
+
         base_path = self._main.sDesktopinstallDirectory
         sys.path.append(base_path)
         sys.path.append(os.path.join(base_path, "PythonFiles", "DesktopPlugin"))
@@ -561,7 +581,7 @@ class Desktop:
         processID = []
         if IsWindows:
             processID = self._get_tasks_list_windows(student_version)
-        if student_version and not processID:
+        if student_version and not processID:  # Opens an instance if processID is an empty list
             self._run_student()
         elif non_graphical or new_aedt_session or not processID:
             # Force new object if no non-graphical instance is running or if there is not an already existing process.
@@ -573,8 +593,12 @@ class Desktop:
         processID2 = []
         if IsWindows:
             processID2 = self._get_tasks_list_windows(student_version)
-        proc = [i for i in processID2 if i not in processID]
-        if not proc:
+        proc = [i for i in processID2 if i not in processID]  # Looking for the "new" process
+        if (
+            not proc and (not new_aedt_session) and aedt_process_id
+        ):  # if it isn't a new aedt session and a process ID is given
+            proc = [aedt_process_id]
+        elif not proc:
             proc = processID2
         if proc == processID2 and len(processID2) > 1:
             self._dispatch_win32(version)
