@@ -1,8 +1,7 @@
-import os
 import os.path
 
-from pyaedt.generic.general_methods import env_path
 from pyaedt import is_ironpython
+from pyaedt.generic.general_methods import env_path
 
 if os.name == "posix" and is_ironpython:
     import subprocessdotnet as subprocess
@@ -195,7 +194,7 @@ class SiwaveSolve(object):
             if os.path.exists(exec_file):
                 with open(exec_file, "r+") as f:
                     content = f.readlines()
-                    if not "SetNumCpus" in content:
+                    if "SetNumCpus" not in content:
                         f.writelines(str.format("SetNumCpus {}", str(self.nbcores)) + "\n")
                         f.writelines("SaveSiw")
                     else:
