@@ -12,8 +12,7 @@ from pyaedt.generic.general_methods import inside_desktop
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modeler.Modeler import Modeler
-from pyaedt.modeler.Object3d import ComponentsSubCircuit3DLayout
-from pyaedt.modeler.Primitives3DLayout import Geometries3DLayout
+from pyaedt.modeler.object3dlayout import ComponentsSubCircuit3DLayout
 from pyaedt.modeler.Primitives3DLayout import Primitives3DLayout
 from pyaedt.modules.LayerStackup import Layers
 
@@ -387,6 +386,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
                 self.arg_with_dim(tolerance),
             ]
         )
+
         return True
 
     @pyaedt_function_handler()
@@ -434,14 +434,13 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
         pos = [poly[0].GetX(), poly[0].GetY()]
         geom_names = self.oeditor.FindObjectsByPoint(self.oeditor.Point().Set(pos[0], pos[1]), layer)
         self.oeditor.Expand(self.arg_with_dim(size), expand_type, replace_original, ["NAME:elements", object_to_expand])
+        self._init_prims()
         if not replace_original:
             new_geom_names = [
                 i
                 for i in self.oeditor.FindObjectsByPoint(self.oeditor.Point().Set(pos[0], pos[1]), layer)
                 if i not in geom_names
             ]
-            if self.is_outside_desktop:
-                self._geometries[new_geom_names[0]] = Geometries3DLayout(self, new_geom_names[0])
             return new_geom_names[0]
         return object_to_expand
 
@@ -565,13 +564,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
             vArg1.append(tool)
         if self.oeditor is not None:
             self.oeditor.Subtract(vArg1)
-        if isinstance(tool, list):
-            for el in tool:
-                if self.is_outside_desktop:
-                    self._geometries.pop(el)
-        else:
-            if self.is_outside_desktop:
-                self._geometries.pop(tool)
+        self._init_prims()
         return True
 
     @pyaedt_function_handler()
@@ -598,10 +591,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
             for el in objectlists:
                 vArg1.append(el)
             self.oeditor.Unite(vArg1)
-            for el in objectlists:
-                if not self.oeditor.FindObjects("Name", el):
-                    if self.is_outside_desktop:
-                        self._geometries.pop(el)
+            self._init_prims()
             return True
         else:
             self.logger.error("Input list must contain at least two elements.")
@@ -631,10 +621,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
             for el in objectlists:
                 vArg1.append(el)
             self.oeditor.Intersect(vArg1)
-            for el in objectlists:
-                if not self.oeditor.FindObjects("Name", el):
-                    if self.is_outside_desktop:
-                        self._geometries.pop(el)
+            self._init_prims()
             return True
         else:
             self.logger.error("Input list must contain at least two elements.")
@@ -668,6 +655,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
         self.oeditor.Duplicate(
             ["NAME:options", "count:=", count], ["NAME:elements", ",".join(objectlists)], direction_vector
         )
+        self._init_prims()
         return True
 
     @pyaedt_function_handler()
@@ -799,7 +787,7 @@ class Modeler3DLayout(Modeler, Primitives3DLayout):
                     pinNames.remove(pinNames[0])
                     pinNames.remove(pinNames[0])
                     break
-        componentPins = [i.GetName() for i in self.edb.core_components.get_pin_from_component(component_name)]
+        componentPins = self.components[component_name].pins
         componentPins.reverse()
         if not pin_map:
             pin_map = []
