@@ -223,7 +223,7 @@ class CircuitComponents(object):
            Use :func:`Circuit.modeler.schematic.create_interface_port` instead.
         """
         warnings.warn("`create_iport` is deprecated. Use `create_interface_port` instead.", DeprecationWarning)
-        return self.create_interface_port(name, posx, posy, angle)
+        return self.create_interface_port(name, [posx, posy], angle)
 
     @pyaedt_function_handler()
     def create_interface_port(self, name, location=[], angle=0):
@@ -977,10 +977,11 @@ class CircuitComponents(object):
                     o.name = name[0]
                     if len(name) == 2:
                         o.schematic_id = name[1]
+                        objID = int(o.schematic_id)
                     else:
                         o.id = int(name[1])
                         o.schematic_id = name[2]
-                    objID = o.id
+                        objID = o.id
                     self.components[objID] = o
         return len(self.components)
 
