@@ -1,4 +1,6 @@
+# -*- coding: utf-8 -*-
 import os
+import random
 import re
 import warnings
 
@@ -79,6 +81,106 @@ class NexximComponents(CircuitComponents):
             self._components_catalog = ComponentCatalog(self)
         return self._components_catalog
 
+    @pyaedt_function_handler()
+    def create_subcircuit(self, location=None, angle=0, name=None, nested_subcircuit_id=None):
+        """Add a new Circuit subcircuit to the design.
+
+        Parameters
+        ----------
+        location : list of float, optional
+            Position on the X axis and Y axis.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        name : str, optional
+            Name of the design. The default is ``None``, in which case
+            a unique name is generated.
+        nested_subcircuit_id : str, optional
+            ID of the nested subcircuit.
+            Example `"U1"`.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Circuit Component Object when successful or ``False`` when failed.
+
+        Examples
+        --------
+        >>> from pyaedt import Circuit
+        >>> cir = Circuit()
+        """
+        if not name:
+            name = generate_unique_name("Circuit")
+
+        if nested_subcircuit_id:
+            parent_name = "{}:{}:{}".format(
+                self._app.design_name.split("/")[0], nested_subcircuit_id, random.randint(1, 10000)
+            )
+        else:
+            parent_name = "{}:{}".format(self._app.design_name.split("/")[0], ":U" + str(random.randint(1, 10000)))
+
+        self._app.odesign.InsertDesign("Circuit Design", name, "", parent_name)
+        if nested_subcircuit_id:
+            pname = "{}:{}".format(self._app.design_name.split("/")[0], nested_subcircuit_id)
+            odes = self._app.oproject.SetActiveDesign(pname)
+            oed = odes.SetActiveEditor("SchematicEditor")
+            objs = oed.GetAllElements()
+            match = [i for i in objs if name in i]
+            o = CircuitComponent(self, tabname=self.tab_name, custom_editor=oed)
+            name = match[0].split(";")
+            o.name = name[0]
+            o.schematic_id = name[2]
+            o.id = int(name[1])
+            return o
+        self.refresh_all_ids()
+        for el in self.components:
+            if name in self.components[el].composed_name:
+                if location:
+                    self.components[el].location = location
+                if angle is not None:
+                    self.components[el].angle = self.arg_with_dim(angle, "°")
+                return self.components[el]
+        return False
+
+    @pyaedt_function_handler()
+    def duplicate(self, component, location=None, angle=0, flip=False):  # pragma: no cover
+        """Add a new subcircuit to the design.
+
+        .. note::
+            This works only in graphical mode.
+
+        Parameters
+        ----------
+        component : class:`pyaedt.modeler.Object3d.CircuitComponent` Circuit Component Object
+            Component to duplicate.
+        location : list of float, optional
+            Position on the X axis and Y axis.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        flip : bool, optional
+            Whether the component should be flipped. The default value is ``False``.
+
+        Returns
+        -------
+        :class:`pyaedt.modeler.Object3d.CircuitComponent` Circuit Component Object
+        when successful or ``False`` when failed.
+        """
+        comp_names = []
+        if isinstance(component, CircuitComponent):
+            comp_names.append(component.composed_name)
+        else:
+            comp_names.append(component)
+        self._modeler.oeditor.Copy(["NAME:Selections", "Selections:=", comp_names])
+        location = self._get_location(location)
+        self._modeler.oeditor.Paste(
+            ["NAME:Attributes", "Page:=", 1, "X:=", location[0], "Y:=", location[1], "Angle:=", angle, "Flip:=", flip]
+        )
+        ids = [id for id in list(self.components.keys())]
+        self.refresh_all_ids()
+        new_ids = [id for id in list(self.components.keys()) if id not in ids]
+        if new_ids:
+            return self.components[new_ids[0]]
+        return False
+
     @pyaedt_function_handler()
     def connect_components_in_series(self, components_to_connect):
         """Connect schematic components in series.
@@ -1060,7 +1162,7 @@ class NexximComponents(CircuitComponents):
         while id < len(pin_lists):
             spicesintax += "%" + str(id) + " "
             id += 1
-        # spicesintax += symbol_name + " "
+            spicesintax += symbol_name + " "
         for el, val in zip(parameter_list, parameter_value):
             if "MOD" in el:
                 spicesintax += "@{} ".format(el)
