@@ -34,6 +34,14 @@ class BoundaryProps(OrderedDict):
             for key, value in props.items():
                 if isinstance(value, (OrderedDict, dict)):
                     OrderedDict.__setitem__(self, key, BoundaryProps(boundary, value))
+                elif isinstance(value, list):
+                    list_els = []
+                    for el in value:
+                        if isinstance(el, (OrderedDict, dict)):
+                            list_els.append(BoundaryProps(boundary, el))
+                        else:
+                            list_els.append(el)
+                    OrderedDict.__setitem__(self, key, list_els)
                 else:
                     OrderedDict.__setitem__(self, key, value)
         self._pyaedt_boundary = boundary
@@ -76,7 +84,10 @@ class BoundaryCommon(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        self._app.oboundary.DeleteBoundaries([self.name])
+        if self.type == "Matrix" or self.type == "Force" or self.type == "Torque":
+            self._app.o_maxwell_parameters.DeleteParameters([self.name])
+        else:
+            self._app.oboundary.DeleteBoundaries([self.name])
         for el in self._app.boundaries:
             if el.name == self.name:
                 self._app.boundaries.remove(el)
@@ -325,22 +336,24 @@ class BoundaryObject(BoundaryCommon, object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        if self.type == "PerfectE":
+        if self.type == "Perfect E":
             self._app.oboundary.AssignPerfectE(self._get_args())
-        elif self.type == "PerfectH":
+        elif self.type == "Perfect H":
             self._app.oboundary.AssignPerfectH(self._get_args())
         elif self.type == "Aperture":
             self._app.oboundary.AssignAperture(self._get_args())
         elif self.type == "Radiation":
             self._app.oboundary.AssignRadiation(self._get_args())
-        elif self.type == "FiniteCond":
+        elif self.type == "Finite Conductivity":
             self._app.oboundary.AssignFiniteCond(self._get_args())
-        elif self.type == "LumpedRLC":
+        elif self.type == "Lumped RLC":
             self._app.oboundary.AssignLumpedRLC(self._get_args())
         elif self.type == "Impedance":
             self._app.oboundary.AssignImpedance(self._get_args())
+        elif self.type == "Layered Impedance":
+            self._app.oboundary.AssignLayeredImp(self._get_args())
         elif self.type == "Anisotropic Impedance":
-            self._app.oboundary.AssignAssignAnisotropicImpedance(self._get_args())
+            self._app.oboundary.AssignAnisotropicImpedance(self._get_args())
         elif self.type == "Primary":
             self._app.oboundary.AssignPrimary(self._get_args())
         elif self.type == "Secondary":
@@ -471,20 +484,22 @@ class BoundaryObject(BoundaryCommon, object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        if self.type == "PerfectE":
+        if self.type == "Perfect E":
             self._app.oboundary.EditPerfectE(self._boundary_name, self._get_args())
-        elif self.type == "PerfectH":
+        elif self.type == "Perfect H":
             self._app.oboundary.EditPerfectH(self._boundary_name, self._get_args())
         elif self.type == "Aperture":
             self._app.oboundary.EditAperture(self._boundary_name, self._get_args())
         elif self.type == "Radiation":
             self._app.oboundary.EditRadiation(self._boundary_name, self._get_args())
-        elif self.type in ["FiniteCond", "Finite Conductivity"]:
+        elif self.type == "Finite Conductivity":
             self._app.oboundary.EditFiniteCond(self._boundary_name, self._get_args())
-        elif self.type == "LumpedRLC":
+        elif self.type == "Lumped RLC":
             self._app.oboundary.EditLumpedRLC(self._boundary_name, self._get_args())
         elif self.type == "Impedance":
             self._app.oboundary.EditImpedance(self._boundary_name, self._get_args())
+        elif self.type == "Layered Impedance":
+            self._app.oboundary.EditLayeredImpedance(self._boundary_name, self._get_args())
         elif self.type == "Anisotropic Impedance":
             self._app.oboundary.EditAssignAnisotropicImpedance(
                 self._boundary_name, self._get_args()
@@ -550,7 +565,7 @@ class BoundaryObject(BoundaryCommon, object):
         elif self.type == "VoltageDrop":
             self._app.oboundary.EditVoltageDrop(self._boundary_name, self._get_args())
         elif self.type == "Current":
-            self._app.oboundary.Current(self._boundary_name, self._get_args())
+            self._app.oboundary.EditCurrent(self._boundary_name, self._get_args())
         elif self.type == "Winding" or self.type == "Winding Group":
             self._app.oboundary.EditWindingGroup(self._boundary_name, self._get_args())  # pragma: no cover
         elif self.type == "Vector Potential":
@@ -611,6 +626,103 @@ class BoundaryObject(BoundaryCommon, object):
         return True
 
 
+class MaxwellParameters(BoundaryCommon, object):
+    """Manages parameter data and execution.
+
+    Examples
+    --------
+
+    Create a matrix in Maxwell3D return a ``pyaedt.modules.Boundary.BoundaryObject``
+
+    >>> from pyaedt import Maxwell2d
+    >>> maxwell_2d = Maxwell2d()
+    >>> coil1 = maxwell_2d.modeler.primitives.create_rectangle([8.5,1.5, 0], [8, 3], True, "Coil_1", "vacuum")
+    >>> coil2 = maxwell_2d.modeler.primitives.create_rectangle([8.5,1.5, 0], [8, 3], True, "Coil_2", "vacuum")
+    >>> maxwell_2d.assign_matrix(["Coil_1", "Coil_2"])
+    """
+
+    def __init__(self, app, name, props, boundarytype):
+        self.auto_update = False
+        self._app = app
+        self._name = name
+        self.props = BoundaryProps(self, OrderedDict(props))
+        self.type = boundarytype
+        self._boundary_name = self.name
+        self.auto_update = True
+
+    @property
+    def name(self):
+        """Boundary Name."""
+        return self._name
+
+    @name.setter
+    def name(self, value):
+        self._name = value
+        self.update()
+
+    @pyaedt_function_handler()
+    def _get_args(self, props=None):
+        """Retrieve arguments.
+
+        Parameters
+        ----------
+        props :
+            The default is ``None``.
+
+        Returns
+        -------
+        list
+            List of boundary properties.
+
+        """
+        if props is None:
+            props = self.props
+        arg = ["NAME:" + self.name]
+        _dict2arg(props, arg)
+        return arg
+
+    @pyaedt_function_handler()
+    def create(self):
+        """Create a boundary.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        if self.type == "Matrix":
+            self._app.o_maxwell_parameters.AssignMatrix(self._get_args())
+        elif self.type == "Torque":
+            self._app.o_maxwell_parameters.AssignTorque(self._get_args())
+        elif self.type == "Force":
+            self._app.o_maxwell_parameters.AssignForce(self._get_args())
+        else:
+            return False
+        return True
+
+    @pyaedt_function_handler()
+    def update(self):
+        """Update the boundary.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+
+        """
+        if self.type == "Matrix":
+            self._app.o_maxwell_parameters.EditMatrix(self._boundary_name, self._get_args())
+        elif self.type == "Force":
+            self._app.o_maxwell_parameters.EditForce(self._boundary_name, self._get_args())
+        elif self.type == "Torque":
+            self._app.o_maxwell_parameters.EditTorque(self._boundary_name, self._get_args())
+        else:
+            return False
+        self._boundary_name = self.name
+        return True
+
+
 class FieldSetup(BoundaryCommon, object):
     """Manages Far Field and Near Field Component data and execution.
 
