@@ -157,6 +157,20 @@ class Setup(object):
         self.omodule.EditSetup(self.name, arg)
         return True
 
+    @pyaedt_function_handler()
+    def delete(self):
+        """Delete actual Setup.
+
+        Returns
+        -------
+        bool
+            `True` if setup is deleted. `False` if it failed.
+        """
+
+        self.omodule.DeleteSetups([self.name])
+        self._app.setups.remove(self)
+        return True
+
     @pyaedt_function_handler()
     def _expression_cache(
         self,
