@@ -5,7 +5,6 @@ import os
 import warnings
 from collections import OrderedDict
 
-from pyaedt.application.Analysis2D import FieldAnalysis2D
 from pyaedt.application.Analysis3D import FieldAnalysis3D
 from pyaedt.generic.constants import MATRIXOPERATIONSQ2D
 from pyaedt.generic.constants import MATRIXOPERATIONSQ3D
@@ -15,7 +14,7 @@ from pyaedt.modules.Boundary import BoundaryObject
 from pyaedt.modules.Boundary import Matrix
 
 
-class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
+class QExtractor(FieldAnalysis3D, object):
     """Extracts a 2D or 3D field analysis.
 
     Parameters
@@ -49,39 +48,24 @@ class QExtractor(FieldAnalysis3D, FieldAnalysis2D, object):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
-        if Q3DType == "Q3D Extractor":
-            FieldAnalysis3D.__init__(
-                self,
-                "Q3D Extractor",
-                projectname,
-                designname,
-                solution_type,
-                setup_name,
-                specified_version,
-                non_graphical,
-                new_desktop_session,
-                close_on_exit,
-                student_version,
-                machine,
-                port,
-            )
-        else:
-            FieldAnalysis2D.__init__(
-                self,
-                "2D Extractor",
-                projectname,
-                designname,
-                solution_type,
-                setup_name,
-                specified_version,
-                non_graphical,
-                new_desktop_session,
-                close_on_exit,
-                student_version,
-                machine,
-                port,
-            )
+        FieldAnalysis3D.__init__(
+            self,
+            Q3DType,
+            projectname,
+            designname,
+            solution_type,
+            setup_name,
+            specified_version,
+            non_graphical,
+            new_desktop_session,
+            close_on_exit,
+            student_version,
+            machine,
+            port,
+            aedt_process_id,
+        )
         self.omatrix = self.odesign.GetModule("ReduceMatrix")
         self.matrices = []
         for el in list(self.omatrix.ListReduceMatrixes()):
@@ -226,6 +210,9 @@ class Q3d(QExtractor, object):
         Port number of which start the oDesktop communication on already existing server.
         This parameter is ignored in new server creation. It works only on 2022R2.
         Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
 
     Examples
     --------
@@ -250,6 +237,7 @@ class Q3d(QExtractor, object):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         QExtractor.__init__(
             self,
@@ -265,6 +253,7 @@ class Q3d(QExtractor, object):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
         self.MATRIXOPERATIONS = MATRIXOPERATIONSQ3D()
 
@@ -787,6 +776,9 @@ class Q2d(QExtractor, object):
         Port number of which start the oDesktop communication on already existing server.
         This parameter is ignored in new server creation. It works only on 2022R2.
         Remote Server must be up and running with command `"ansysedt.exe -grpcsrv portnum"`.
+    aedt_process_id : int, optional
+        Only used when ``new_desktop_session = False``, specifies by process ID which instance
+        of Electronics Desktop to point PyAEDT at.
 
     Examples
     --------
@@ -827,6 +819,7 @@ class Q2d(QExtractor, object):
         student_version=False,
         machine="",
         port=0,
+        aedt_process_id=None,
     ):
         QExtractor.__init__(
             self,
@@ -842,6 +835,7 @@ class Q2d(QExtractor, object):
             student_version,
             machine,
             port,
+            aedt_process_id,
         )
         self.MATRIXOPERATIONS = MATRIXOPERATIONSQ2D()
 
@@ -1014,7 +1008,7 @@ class Q2d(QExtractor, object):
 
         props = OrderedDict({"Edges": a, "UseCoating": False, "Radius": ra, "Ratio": str(ratio)})
 
-        bound = BoundaryObject(self, name, props, "FiniteCond")
+        bound = BoundaryObject(self, name, props, "Finite Conductivity")
         if bound.create():
             self.boundaries.append(bound)
             return bound
